VitureSensorData class

Constructors

VitureSensorData.pose({required double roll, required double pitch, required double yaw, required double quatW, required double quatX, required double quatY, required double quatZ, required int timestamp})
const
VitureSensorData.raw({required double gyroX, required double gyroY, required double gyroZ, required double accelX, required double accelY, required double accelZ, required double magX, required double magY, required double magZ, required double temperature, required int timestamp, required int vsync})
const

Properties

accelX double
final
accelY double
final
accelZ double
final
gyroX double
final
gyroY double
final
gyroZ double
final
hashCode int
The hash code for this object.
no setterinherited
isRaw bool
final
magX double
final
magY double
final
magZ double
final
pitch double
final
quatW double
final
quatX double
final
quatY double
final
quatZ double
final
roll double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature double
final
timestamp int
final
vsync int
final
yaw double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited