XRPoseCallback typedef
@brief Callback invoked when a new pose sample is available, This function returns pose data at the Camera's frequency (25 Hz). In most cases, this interface can be ignored.
@param pose Array of 7 floats: px, py, pz, qw, qx, qy, qz.
@param timestamp Monotonic timestamp in seconds.
Implementation
typedef XRPoseCallback =
ffi.Pointer<ffi.NativeFunction<XRPoseCallbackFunction>>;