VitureKit class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
no setter
- isHeadTrackingActive → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sensorStream
→ Stream<
VitureSensorData> -
no setter
-
stateStream
→ Stream<
VitureStateEvent> -
no setter
Methods
-
connect(
) → Future< void> -
disconnect(
) → Future< void> -
dispose(
) → Future< void> -
getBrightnessLevel(
{bool setDarwinOpenExclusive = false}) → Future< int?> -
getSdkVersion(
) → Future< String> -
getVolumeLevel(
{bool setDarwinOpenExclusive = false}) → Future< int?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseHeadTracking(
) → Future< void> -
setBrightnessLevel(
int level, {bool setDarwinOpenExclusive = false}) → Future< void> -
setHeadTrackingEnabled(
bool enabled, {bool setDarwinOpenExclusive = false}) → Future< void> -
setVolumeLevel(
int level, {bool setDarwinOpenExclusive = false}) → Future< void> -
startHeadTracking(
{VitureImuFrequency imuFrequency = VitureImuFrequency.freq120Hz, bool setDarwinOpenExclusive = false}) → Future< HeadTrackingResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- sdkVersion → String
-
no setter
- sdkVersionMajor → int
-
no setter
- sdkVersionMinor → int
-
no setter
- sdkVersionPatch → int
-
no setter
Static Methods
-
fetchHidapiVitureProductIds(
{bool setDarwinOpenExclusive = false}) → int?