LogHook typedef
@brief Log hook function type
This callback is invoked for each log message generated by the library. It allows external applications to capture, filter, or redirect log messages to custom logging systems (files, remote servers, crash reporting, etc.).
@param level Log level (0: None, 1: Error, 2: Info, 3: Debug) @param tag Log tag (typically "libglasses") @param message Log message content
Implementation
typedef LogHook = ffi.Pointer<ffi.NativeFunction<LogHookFunction>>;